.. jef documentation master file, created by
   sphinx-quickstart on Wed May 14 11:33:42 2025.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

jef documentation
=================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   api/jef